##########
Django DDP
##########

.. image:: _static/django-ddp-logo.png
        :alt: django-ddp — reactive ★ realtime ★ relational ★ robust
        :align: center

.. rubric::
        Django DDP lets you create websites and mobile apps that are 
        reactive, realtime, relational & robust -- using Django and 
        Meteor together with the smallest server (and environmental) 
        footprint.

Contents
--------

.. toctree::
        :maxdepth: 2

        readme
        tutorial/index
        admin/index
        devel/index
        reference/index

* :ref:`genindex`
* :ref:`modindex`
* :ref:`search`

.. _pypi: https://pypi.python.org/pypi/django-ddp
